@@ -1,6 +1,6 @@
 #!/bin/sh
 # Executing TCL-interpreter #\
-echo -e "Trying interpreters...\n" && export no_exit_on_failed_exec=1 && shopt -s execfail 2>/dev/null; true && { echo "Trying tclsh..."; exec tclsh "$0" "$@" 2>/dev/null || echo "Trying tcl..."; exec tcl "$0" "$@" 2>/dev/null || echo -e "No valuable interpreter on $(hostname) for the ListServer!\n\nYOU NEED TCL INSTALLED ON THE REMOTE SYSTEM\n\nExiting..."; }
+echo -e "Trying interpreters...\n" && no_exit_on_failed_exec=1 && export no_exit_on_failed_exec && shopt -s execfail 2>/dev/null; true && { echo "Trying tclsh..."; exec tclsh "$0" "$@" 2>/dev/null || echo "Trying tcl..."; exec tcl "$0" "$@" 2>/dev/null || echo -e "No valuable interpreter on $(hostname) for the ListServer!\n\nYOU NEED TCL INSTALLED ON THE REMOTE SYSTEM\n\nExiting..."; }
 
 #############################################################
 # SecPanel - ListServer
@@ -61,6 +61,7 @@ proc GiveList {sock} {
 	set dir [lindex [split $input \t] 0]
 	set hmode [lindex [split $input \t] 1]
 
+	# home dir listing
 	if {$dir == "++InitListing"} {
 	    if [info exists env(HOME)] {
 		set dir $env(HOME)
@@ -108,7 +109,7 @@ proc GiveList {sock} {
 	}
 
 	if {$dolist} {
-	    set fl [open "| ls -$ls [quote_space [string range $dir $range end]]" r]
+	    set fl [open "| ls -$ls [quote_space [string range $dir $range end]]/" r]
 	    while {[gets $fl line] >= 0} {
 		puts $sock $line
 	    }
@@ -155,7 +156,7 @@ proc hostinfo {} {
 hostinfo
 
 set kc 0
-while {[catch {set main [socket -server Accept -myaddr 127.0.0.1 9920]} err] > 0} {
+while {[catch {set main [socket -server Accept -myaddr 127.0.0.1 <listserverport-XXXXX>]} err] > 0} {
     puts "Listserver error: $err"
     if {! $kc} {
 	if [file exists "$env(HOME)/.listserver.pid"] {
@@ -176,7 +177,7 @@ puts -nonewline $pf [pid]
 close $pf
 
 # Tell SecPanel that we are prepared to send filelistings
-set callbacksocket [socket localhost 9910]
+set callbacksocket [socket localhost <controlremoteport-XXXXX>]
 fconfigure $callbacksocket -buffering line
 puts $callbacksocket "opengui $clientpass"
 puts "Sent CallBack to SecPanel"
